@@ -10,31 +10,30 @@ matplotlib.use("TkAgg")
 TIME EVOLUTION EXAMPLE 1: Vortex trains
 
 """
-p = Plot
 
 if __name__ == "__main__":
 
-    N = 20
+    N = 50
 
     sq_array = SquareArray(N, N)
-    x = np.ones(sq_array._Nj())
-    x[np.random.rand(sq_array._Nj()) < 0.3] = 0
-    x = np.random.rand(sq_array._Nj())
-    print(len(x))
-    sq_array.set_inductance_factors(x)
+    # sq_array.set_inductance_factors(1)
+    # x = np.ones(sq_array._Nj())
+    # x[np.random.rand(sq_array._Nj()) < 0.3] = 0
+    # x = np.random.rand(sq_array._Nj())
+    # print(len(x))
+    # sq_array.set_inductance_factors(x)
     # print(sq_array._get_mixed_inductance_mask())
     # sq_array.set_capacitance_factors(1)
 
     f = 0.05
-    Is = 0.6 * sq_array.horizontal_junctions()
-    T = 0
+    W = 1
+    Is = 0.6 * sq_array.current_base(angle=0)[:, None, None] * np.ones((1, W, 1))
+    T = 0.01
     dt = 0.02
     Nt = 10000
     store_stepsize = 25
     ts = np.arange(0, Nt, store_stepsize)
-    a = np.random.rand(3,)
-    b = np.atleast_2d(a)
-    print(b.shape )
+
     problem = TimeEvolutionProblem(sq_array, time_step=dt,
                                    time_step_count=Nt, current_sources=Is,
                                    frustration=f, temperature=T,
@@ -42,7 +41,7 @@ if __name__ == "__main__":
     tic = time.perf_counter()
     out = problem.compute()
     print(time.perf_counter() - tic)
-    # out.animate(arrow_quantity="Isup", face_quantity="flux", show_face_quantity=True, face_quantity_clim=[-1, 2],
+    # out.animate(junction_quantity="Isup", face_quantity="flux", face_quantity_clim=[-1, 2],
     #             figsize=[10, 10])
-    out.animate()
+    # out.animate()
     plt.show()
